package controller

import (
	"github.com/gin-gonic/gin"
	"iot_manager_service/app/device/dao"
	"iot_manager_service/app/device/model"
	"iot_manager_service/app/device/service"
	"iot_manager_service/util"
	"math"
	"net/http"
	"strconv"
)

// 垃圾桶道路管理对象
var GarbageWay = new(garbageWayCtl)

type garbageWayCtl struct{}

func (c *garbageWayCtl) Detail(ctx *gin.Context) {
	id, e := strconv.Atoi(ctx.Query("id"))
	if e != nil {
		ctx.JSON(http.StatusOK, util.ParamsInvalidResponse(e.Error(), nil))
		return
	}

	device, err := service.GarbageWayGroupService.Get(id)
	if err != nil {
		ctx.JSON(http.StatusOK, err)
		return
	}
	ctx.JSON(http.StatusOK, util.SuccessResponse(util.Succeeded, device))
}

func (c *garbageWayCtl) List(ctx *gin.Context) {
	searchValue := ctx.Query("searchValue")
	current, _ := strconv.Atoi(ctx.Query("current"))
	size, _ := strconv.Atoi(ctx.Query("size"))
	if current == 0 {
		current = 1
	}
	if size <= 0 || size > 100 {
		size = 10
	}
	devices, err := service.GarbageWayGroupService.List(searchValue, current, size)
	if err != nil {
		ctx.JSON(http.StatusOK, err)
		return
	}
	pages := math.Ceil(float64(len(devices)) / float64(size))
	rsp := model.RsqGarbageWayGroupList{
		Current: current,
		Size:    size,
		Total:   len(devices),
		Pages:   int(pages),
	}
	for _, device := range devices {

		rsp.Records = append(rsp.Records, device)
	}
	ctx.JSON(http.StatusOK, util.SuccessResponse(util.Succeeded, rsp))
}

func (c *garbageWayCtl) CreateOrUpdate(ctx *gin.Context) {
	var req dao.GarbageWayGroup
	if err := ctx.ShouldBindJSON(&req); err != nil {
		ctx.JSON(http.StatusOK, util.ParamsInvalidResponse(err.Error(), nil))
		return
	}
	err := service.GarbageWayGroupService.CreateOrUpdate(req)
	ctx.JSON(http.StatusOK, err)
}

func (c *garbageWayCtl) Remove(ctx *gin.Context) {
	var req *model.ReqGarbageWayGroupRemove
	if err := ctx.ShouldBindJSON(&req); err != nil {
		ctx.JSON(http.StatusOK, util.ParamsInvalidResponse(err.Error(), nil))
		return
	}
	err := service.GarbageWayGroupService.Remove(req.IDs)
	if err != nil {
		ctx.JSON(http.StatusOK, err)
		return
	}
	ctx.JSON(http.StatusOK, util.SuccessResponse(util.Succeeded, nil))
}

func (c *garbageWayCtl) GetList(ctx *gin.Context) {
	devices, err := service.GarbageWayGroupService.GetList()
	if err != nil {
		ctx.JSON(http.StatusOK, err)
		return
	}
	ctx.JSON(http.StatusOK, util.SuccessResponse(util.Succeeded, devices))
}
