package dao

import (
	"github.com/jinzhu/gorm"
	"time"
)

// OnDemandSensor 灯随车走
type OnDemandSensor struct {
	ID          int       `gorm:"primary key" json:"id"`                //编号
	Name        string    `gorm:"type:varchar(64)" json:"name"`         //名称
	SN          string    `gorm:"type:varchar(60)" json:"sn"`           //唯一编码
	BrandID     int       `gorm:"type:int" json:"brandID"`              //设备名称
	ModelID     int       `gorm:"type:int" json:"modelID"`              //设备型号
	LampPoleID  int       `gorm:"type:int" json:"lampPoleID"`           //所属灯杆
	SensorPhoto string    `gorm:"type:varchar(255)" json:"sensorPhoto"` //传感器照片
	TenantID    string    `gorm:"type:varchar(12)" json:"tenantID"`     //租户ID
	InstallTime time.Time `gorm:"type:date" json:"installTime"`         //安装时间
	CreateTime  time.Time `gorm:"type:date" json:"creatTime"`           //新增时间
	CreateUser  string    `gorm:"type:varchar(60)" json:"createUser"`   //新增记录操作用户ID
	UpdateTime  time.Time `gorm:"type:datetime" json:"updateTime"`      //修改时间
	UpdateUser  string    `gorm:"type:varchar(60)" json:"updateUser"`   //修改用户
	IsDeleted   int       `gorm:"type:int; default 0" json:"isDeleted"` //是否删除：0=未删除，1=删除
	Status      int       `gorm:"type:int; default 0" json:"status"`    //状态0=正常，1=异常
}

func (OnDemandSensor) TableName() string {
	return "t_dev_on_demand_sensor"
}

func (c OnDemandSensor) Delete() error {
	return Db.Debug().Model(&c).Where("id = ?", c.ID).Updates(map[string]interface{}{"update_time": c.UpdateTime,
		"update_user": c.UpdateUser, "is_deleted": c.IsDeleted}).Error
}

func (c OnDemandSensor) IsExistedBySN() bool {
	var count = 0
	_ = Db.Debug().Model(&c).Where("  sn = ? and is_deleted = ?",
		c.SN, c.IsDeleted).Count(&count).Error
	return count > 0
}

func (c OnDemandSensor) IsExistedByNameAndCode() bool {
	var devices []OnDemandSensor
	err := Db.Debug().Model(&c).Where("sn = ? and is_deleted = ?",
		c.SN, c.IsDeleted).Find(&devices).Error
	//如果查询不到，返回相应的错误
	if gorm.IsRecordNotFoundError(err) {
		return false
	}
	for _, d := range devices {
		if d.ID != c.ID {
			return true
		}
	}
	return false
}

func (c *OnDemandSensor) Create() error {
	return Db.Debug().Model(&c).Save(&c).Error
}

func (c *OnDemandSensor) Update() error {
	return Db.Debug().Model(&c).Where(" id = ? ", c.ID).Update(&c).Error
}

func (c *OnDemandSensor) GetDevice() error {
	err := Db.Debug().Model(&c).Where(" id = ? ", c.ID).Scan(&c).Error
	return err
}

func (c OnDemandSensor) GetDevices(offset, limit int) ([]OnDemandSensor, error) {
	var devices []OnDemandSensor
	err := Db.Debug().Model(&c).Where(" name like ? ", "%"+c.Name+"%").Offset(offset).Limit(limit).Find(&devices).Error
	return devices, err
}

func (c OnDemandSensor) GetAllDevices() ([]*OnDemandSensor, error) {
	var devices []*OnDemandSensor
	err := Db.Debug().Model(&c).Where(" tenant_id = ? and is_deleted = ? ", c.TenantID, c.IsDeleted).Scan(&devices).Error
	return devices, err
}
